@@ -35,11 +35,6 @@ GType arv_debug_level_get_type	(void) G_GNUC_CONST;
 #define ARV_TYPE_DOM_NODE_TYPE	(arv_dom_node_type_get_type())
 GType arv_dom_node_type_get_type	(void) G_GNUC_CONST;
 
-/* Enumerations from "arvgc.h" */
-
-#define ARV_TYPE_GC_ERROR	(arv_gc_error_get_type())
-GType arv_gc_error_get_type	(void) G_GNUC_CONST;
-
 /* Enumerations from "arvgcpropertynode.h" */
 
 #define ARV_TYPE_GC_PROPERTY_NODE_TYPE	(arv_gc_property_node_type_get_type())
@@ -103,6 +98,22 @@ GType arv_gvsp_content_type_get_type	(void) G_GNUC_CONST;
 #define ARV_TYPE_GVSP_PAYLOAD_TYPE	(arv_gvsp_payload_type_get_type())
 GType arv_gvsp_payload_type_get_type	(void) G_GNUC_CONST;
 
+/* Enumerations from "arvuvcp.h" */
+
+#define ARV_TYPE_UVCP_PACKET_TYPE	(arv_uvcp_packet_type_get_type())
+GType arv_uvcp_packet_type_get_type	(void) G_GNUC_CONST;
+
+#define ARV_TYPE_UVCP_COMMAND	(arv_uvcp_command_get_type())
+GType arv_uvcp_command_get_type	(void) G_GNUC_CONST;
+
+/* Enumerations from "arvuvsp.h" */
+
+#define ARV_TYPE_UVSP_PACKET_TYPE	(arv_uvsp_packet_type_get_type())
+GType arv_uvsp_packet_type_get_type	(void) G_GNUC_CONST;
+
+#define ARV_TYPE_UVSP_PAYLOAD_TYPE	(arv_uvsp_payload_type_get_type())
+GType arv_uvsp_payload_type_get_type	(void) G_GNUC_CONST;
+
 G_END_DECLS
 
 #endif /* ARV_ENUM_TYPES_H */
